=== modified file 'libmysql/client.c'
--- libmysql/client.c	2008-07-01 10:46:26 +0000
+++ libmysql/client.c	2008-07-01 20:52:03 +0000
@@ -38,12 +38,7 @@
 
 #include "mysql.h"
 
-/* Windows lacks a netdb.h */
-#ifdef __WIN__
-#include <Ws2tcpip.h>
-#else
 #include <netdb.h>
-#endif
 
 /* Remove client convenience wrappers */
 #undef max_allowed_packet

=== modified file 'mysys/mf_iocache.c'
--- mysys/mf_iocache.c	2008-06-25 05:29:13 +0000
+++ mysys/mf_iocache.c	2008-07-01 20:14:24 +0000
@@ -1644,11 +1644,10 @@
   {
     /* Of no overlap, write everything without buffering */
     if (pos + Count <= info->pos_in_file)
-      return my_pwrite(info->file, Buffer, Count, pos,
-		       info->myflags | MY_NABP);
+      return (pwrite(info->file, Buffer, Count, pos) == 0);
     /* Write the part of the block that is before buffer */
     length= (uint) (info->pos_in_file - pos);
-    if (my_pwrite(info->file, Buffer, length, pos, info->myflags | MY_NABP))
+    if (pwrite(info->file, Buffer, length, pos) == 0)
       info->error= error= -1;
     Buffer+=length;
     pos+=  length;

=== modified file 'mysys/mf_keycache.c'
--- mysys/mf_keycache.c	2008-07-01 08:15:04 +0000
+++ mysys/mf_keycache.c	2008-07-01 20:14:24 +0000
@@ -2205,11 +2205,10 @@
                 The call is thread safe because only the current
                 thread might change the block->hash_link value
               */
-              error= my_pwrite(block->hash_link->file,
-                               block->buffer+block->offset,
-                               block->length - block->offset,
-                               block->hash_link->diskpos+ block->offset,
-                               MYF(MY_NABP | MY_WAIT_IF_FULL));
+              error= (pwrite(block->hash_link->file,
+                             block->buffer+block->offset,
+                             block->length - block->offset,
+                             block->hash_link->diskpos+ block->offset) == 0);
               keycache_pthread_mutex_lock(&keycache->cache_lock);
 
               /* Block status must not have changed. */
@@ -2432,8 +2431,7 @@
       Here other threads may step in and register as secondary readers.
       They will register in block->wqueue[COND_FOR_REQUESTED].
     */
-    got_length= my_pread(block->hash_link->file, block->buffer,
-                         read_length, block->hash_link->diskpos, MYF(0));
+    got_length= pread(block->hash_link->file, block->buffer, read_length, block->hash_link->diskpos);
     keycache_pthread_mutex_lock(&keycache->cache_lock);
     /*
       The block can now have been marked for free (in case of
@@ -2594,8 +2592,7 @@
         */
         keycache->global_cache_read++;
         keycache_pthread_mutex_unlock(&keycache->cache_lock);
-        error= (my_pread(file, (uchar*) buff, read_length,
-                         filepos + offset, MYF(MY_NABP)) != 0);
+        error= (pread(file, (uchar*) buff, read_length, filepos + offset) == 0);
         keycache_pthread_mutex_lock(&keycache->cache_lock);
         goto next_block;
       }
@@ -2690,7 +2687,7 @@
 
   if (locked_and_incremented)
     keycache_pthread_mutex_unlock(&keycache->cache_lock);
-  if (my_pread(file, (uchar*) buff, length, filepos, MYF(MY_NABP)))
+  if (pread(file, (uchar*) buff, length, filepos))
     error= 1;
   if (locked_and_incremented)
     keycache_pthread_mutex_lock(&keycache->cache_lock);
@@ -2989,7 +2986,7 @@
     /* Force writing from buff into disk. */
     keycache->global_cache_w_requests++;
     keycache->global_cache_write++;
-    if (my_pwrite(file, buff, length, filepos, MYF(MY_NABP | MY_WAIT_IF_FULL)))
+    if (pwrite(file, buff, length, filepos) == 0)
       DBUG_RETURN(1);
     /* purecov: end */
   }
@@ -3064,8 +3061,7 @@
           /* Used in the server. */
           keycache->global_cache_write++;
           keycache_pthread_mutex_unlock(&keycache->cache_lock);
-          if (my_pwrite(file, (uchar*) buff, read_length, filepos + offset,
-                        MYF(MY_NABP | MY_WAIT_IF_FULL)))
+          if (pwrite(file, (uchar*) buff, read_length, filepos + offset) == 0)
             error=1;
           keycache_pthread_mutex_lock(&keycache->cache_lock);
         }
@@ -3232,8 +3228,7 @@
     keycache->global_cache_write++;
     if (locked_and_incremented)
       keycache_pthread_mutex_unlock(&keycache->cache_lock);
-    if (my_pwrite(file, (uchar*) buff, length, filepos,
-		  MYF(MY_NABP | MY_WAIT_IF_FULL)))
+    if (pwrite(file, (uchar*) buff, length, filepos) == 0)
       error=1;
     if (locked_and_incremented)
       keycache_pthread_mutex_lock(&keycache->cache_lock);
@@ -3459,11 +3454,10 @@
                   (BLOCK_READ | BLOCK_IN_FLUSH | BLOCK_CHANGED | BLOCK_IN_USE));
       block->status|= BLOCK_IN_FLUSHWRITE;
       keycache_pthread_mutex_unlock(&keycache->cache_lock);
-      error= my_pwrite(file,
-                       block->buffer+block->offset,
-                       block->length - block->offset,
-                       block->hash_link->diskpos+ block->offset,
-                       MYF(MY_NABP | MY_WAIT_IF_FULL));
+      error= (pwrite(file,
+                     block->buffer+block->offset,
+                     block->length - block->offset,
+                     block->hash_link->diskpos+ block->offset) == 0);
       keycache_pthread_mutex_lock(&keycache->cache_lock);
       keycache->global_cache_write++;
       if (error)

=== modified file 'sql/filesort.cc'
--- sql/filesort.cc	2008-06-25 05:29:13 +0000
+++ sql/filesort.cc	2008-07-01 19:42:41 +0000
@@ -1081,8 +1081,7 @@
 
   if ((count=(uint) min((ha_rows) buffpek->max_keys,buffpek->count)))
   {
-    if (my_pread(fromfile->file,(uchar*) buffpek->base,
-		 (length= rec_length*count),buffpek->file_pos,MYF_RW))
+    if (pread(fromfile->file,(uchar*) buffpek->base, (length= rec_length*count),buffpek->file_pos) == 0)
       return((uint) -1);			/* purecov: inspected */
     buffpek->key=buffpek->base;
     buffpek->file_pos+= length;			/* New filepos */

=== modified file 'sql/handler.cc'
--- sql/handler.cc	2008-06-29 20:10:28 +0000
+++ sql/handler.cc	2008-07-01 19:42:41 +0000
@@ -2710,7 +2710,7 @@
 {
   char path[FN_REFLEN];
   File file;
-  int result= 1;
+  bool result= true;
   DBUG_ENTER("update_frm_version");
 
   /*
@@ -2734,8 +2734,11 @@
 
     int4store(version, MYSQL_VERSION_ID);
 
-    if ((result= my_pwrite(file,(uchar*) version,4,51L,MYF_RW)))
+    if (pwrite(file, (uchar*)version, 4, 51L) == 0)
+    {
+      result= false;
       goto err;
+    }
 
     for (entry=(TABLE*) hash_first(&open_cache,(uchar*) key,key_length, &state);
          entry;

=== modified file 'sql/log.cc'
--- sql/log.cc	2008-07-01 08:15:04 +0000
+++ sql/log.cc	2008-07-01 19:42:41 +0000
@@ -3851,14 +3851,7 @@
       my_off_t offset= BIN_LOG_HEADER_SIZE + FLAGS_OFFSET;
       my_off_t org_position= my_tell(log_file.file, MYF(0));
       uchar flags= 0;            // clearing LOG_EVENT_BINLOG_IN_USE_F
-      my_pwrite(log_file.file, &flags, 1, offset, MYF(0));
-      /*
-        Restore position so that anything we have in the IO_cache is written
-        to the correct position.
-        We need the seek here, as my_pwrite() is not guaranteed to keep the
-        original position on system that doesn't support pwrite().
-      */
-      my_seek(log_file.file, org_position, MY_SEEK_SET, MYF(0));
+      pwrite(log_file.file, &flags, 1, offset);
     }
 
     /* this will cleanup IO_CACHE, sync and close the file */

=== modified file 'sql/sql_table.cc'
--- sql/sql_table.cc	2008-06-30 07:09:25 +0000
+++ sql/sql_table.cc	2008-07-01 19:42:41 +0000
@@ -333,8 +333,7 @@
   uint io_size= global_ddl_log.io_size;
   DBUG_ENTER("read_ddl_log_file_entry");
 
-  if (my_pread(file_id, file_entry_buf, io_size, io_size * entry_no,
-               MYF(MY_WME)) != io_size)
+  if (pread(file_id, file_entry_buf, io_size, io_size * entry_no) != io_size)
     error= TRUE;
   DBUG_RETURN(error);
 }
@@ -357,8 +356,8 @@
   char *file_entry_buf= (char*)global_ddl_log.file_entry_buf;
   DBUG_ENTER("write_ddl_log_file_entry");
 
-  if (my_pwrite(file_id, (uchar*)file_entry_buf,
-                IO_SIZE, IO_SIZE * entry_no, MYF(MY_WME)) != IO_SIZE)
+  if (pwrite(file_id, (uchar*)file_entry_buf,
+             IO_SIZE, IO_SIZE * entry_no) != IO_SIZE)
     error= TRUE;
   DBUG_RETURN(error);
 }

=== modified file 'sql/table.cc'
--- sql/table.cc	2008-07-01 08:15:04 +0000
+++ sql/table.cc	2008-07-01 19:42:41 +0000
@@ -749,8 +749,7 @@
     DBUG_PRINT("info", ("extra segment size is %u bytes", n_length));
     if (!(next_chunk= buff= (uchar*) my_malloc(n_length, MYF(MY_WME))))
       goto err;
-    if (my_pread(file, buff, n_length, record_offset + share->reclength,
-                 MYF(MY_NABP)))
+    if (pread(file, buff, n_length, record_offset + share->reclength) == 0)
     {
       goto err;
     }
@@ -903,8 +902,7 @@
                                      rec_buff_length)))
     goto err;                                   /* purecov: inspected */
   share->default_values= record;
-  if (my_pread(file, record, (size_t) share->reclength,
-               record_offset, MYF(MY_NABP)))
+  if (pread(file, record, (size_t) share->reclength, record_offset) == 0)
     goto err;                                   /* purecov: inspected */
 
   VOID(my_seek(file,pos+288,MY_SEEK_SET,MYF(0)));

=== modified file 'sql/unireg.cc'
--- sql/unireg.cc	2008-06-25 05:29:13 +0000
+++ sql/unireg.cc	2008-07-01 19:42:41 +0000
@@ -240,9 +240,8 @@
 
   int2store(fileinfo+59,db_file->extra_rec_buf_length());
 
-  if (my_pwrite(file, fileinfo, 64, 0L, MYF_RW) ||
-      my_pwrite(file, keybuff, key_info_length,
-		(ulong) uint2korr(fileinfo+6),MYF_RW))
+  if (pwrite(file, fileinfo, 64, 0L) == 0 ||
+      pwrite(file, keybuff, key_info_length, (ulong) uint2korr(fileinfo+6)) == 0)
     goto err;
   VOID(my_seek(file,
 	       (ulong) uint2korr(fileinfo+6)+ (ulong) key_buff_length,

=== modified file 'vio/Makefile.am'
--- vio/Makefile.am	2008-07-01 20:43:04 +0000
+++ vio/Makefile.am	2008-07-01 21:56:02 +0000
@@ -13,8 +13,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-AM_CPPFLAGS =		-I$(top_builddir)/include -I$(top_srcdir)/include \
-			$(openssl_includes)
+AM_CPPFLAGS =		-I$(top_builddir)/include -I$(top_srcdir)/include
 pkglib_LTLIBRARIES =	libvio.la
 libvio_la_SOURCES = 
 libvio_la_LIBADD =      libviolt.la

=== removed file 'vio/test-ssl.c'
--- vio/test-ssl.c	2008-06-25 05:29:13 +0000
+++ vio/test-ssl.c	1970-01-01 00:00:00 +0000
@@ -1,149 +0,0 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-#include <my_global.h>
-#if defined(HAVE_OPENSSL) && !defined(__NETWARE__)
-#include <my_sys.h>
-#include <m_string.h>
-#include <m_ctype.h>
-#include "mysql.h"
-#include "errmsg.h"
-#include <my_dir.h>
-#include <my_getopt.h>
-#include <signal.h>
-#include <violite.h>
-
-const char *VER="0.2";
-
-
-#ifndef DBUG_OFF
-const char *default_dbug_option="d:t:O,-";
-#endif
-
-void
-fatal_error(	const char*	r)
-{
-	perror(r);
-	exit(0);
-}
-
-void
-print_usage()
-{
-	printf("viossl-test: testing SSL virtual IO. Usage:\n");
-	printf("viossl-test server-key server-cert client-key client-cert [CAfile] [CApath]\n");
-}
-
-
-int
-main(int argc, char**	argv)
-{
-  char*	server_key = 0,	*server_cert = 0;
-  char*	client_key = 0,	*client_cert = 0;
-  char*	ca_file = 0,	*ca_path = 0;
-  char*	cipher=0;
-  int	child_pid,sv[2];
-  my_bool unused;
-  struct st_VioSSLFd* ssl_acceptor= 0;
-  struct st_VioSSLFd* ssl_connector= 0;
-  Vio* client_vio=0, *server_vio=0;
-  MY_INIT(argv[0]);
-  DBUG_PROCESS(argv[0]);
-  DBUG_PUSH(default_dbug_option);
-
-  if (argc<5)
-  {
-    print_usage();
-    return 1;
-  }
-
-  server_key = argv[1];
-  server_cert = argv[2];
-  client_key = argv[3];
-  client_cert = argv[4];
-  if (argc>5)
-    ca_file = argv[5];
-  if (argc>6)
-    ca_path = argv[6];
-  printf("Server key/cert : %s/%s\n", server_key, server_cert);
-  printf("Client key/cert : %s/%s\n", client_key, client_cert);
-  if (ca_file!=0)
-    printf("CAfile          : %s\n", ca_file);
-  if (ca_path!=0)
-    printf("CApath          : %s\n", ca_path);
-
-
-  if (socketpair(PF_UNIX, SOCK_STREAM, IPPROTO_IP, sv)==-1)
-    fatal_error("socketpair");
-
-  ssl_acceptor = new_VioSSLAcceptorFd(server_key, server_cert, ca_file,
-				      ca_path, cipher);
-  ssl_connector = new_VioSSLConnectorFd(client_key, client_cert, ca_file,
-					ca_path, cipher);
-
-  client_vio = (struct st_vio*)my_malloc(sizeof(struct st_vio),MYF(0));
-  client_vio->sd = sv[0];
-  client_vio->vioblocking(client_vio, 0, &unused);
-  sslconnect(ssl_connector,client_vio,60L);
-  server_vio = (struct st_vio*)my_malloc(sizeof(struct st_vio),MYF(0));
-  server_vio->sd = sv[1];
-  server_vio->vioblocking(client_vio, 0, &unused);
-  sslaccept(ssl_acceptor,server_vio,60L);
-
-  printf("Socketpair: %d , %d\n", client_vio->sd, server_vio->sd);
-
-  child_pid = fork();
-  if (child_pid==-1) {
-    my_free((uchar*)ssl_acceptor,MYF(0));
-    my_free((uchar*)ssl_connector,MYF(0));
-    fatal_error("fork");
-  }
-  if (child_pid==0)
-  {
-    /* child, therefore, client */
-    char	xbuf[100];
-    int	r = vio_read(client_vio,xbuf, sizeof(xbuf));
-    if (r<=0) {
-      my_free((uchar*)ssl_acceptor,MYF(0));
-      my_free((uchar*)ssl_connector,MYF(0));
-      fatal_error("client:SSL_read");
-    }
-    xbuf[r] = 0;
-    printf("client:got %s\n", xbuf);
-    my_free((uchar*)client_vio,MYF(0));
-    my_free((uchar*)ssl_acceptor,MYF(0));
-    my_free((uchar*)ssl_connector,MYF(0));
-  }
-  else
-  {
-    const char*	s = "Huhuhuh";
-    int		r = vio_write(server_vio,(uchar*)s, strlen(s));
-    if (r<=0) {
-      my_free((uchar*)ssl_acceptor,MYF(0));
-      my_free((uchar*)ssl_connector,MYF(0));
-      fatal_error("server:SSL_write");
-    }
-    my_free((uchar*)server_vio,MYF(0));
-    my_free((uchar*)ssl_acceptor,MYF(0));
-    my_free((uchar*)ssl_connector,MYF(0));
-  }
-  return 0;
-}
-#else /* HAVE_OPENSSL */
-
-int main() {
-return 0;
-}
-#endif /* HAVE_OPENSSL */

=== removed file 'vio/test-sslclient.c'
--- vio/test-sslclient.c	2008-06-25 05:29:13 +0000
+++ vio/test-sslclient.c	1970-01-01 00:00:00 +0000
@@ -1,101 +0,0 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-#include <my_global.h>
-#ifdef HAVE_OPENSSL
-#include <my_sys.h>
-#include <m_string.h>
-#include <m_ctype.h>
-#include "mysql.h"
-#include "errmsg.h"
-#include <my_dir.h>
-#include <my_getopt.h>
-#include <signal.h>
-#include <violite.h>
-
-const char *VER="0.2";
-
-
-#ifndef DBUG_OFF
-const char *default_dbug_option="d:t:O,-";
-#endif
-
-void
-fatal_error(	const char*	r)
-{
-	perror(r);
-	exit(0);
-}
-
-int
-main(	int	argc __attribute__((unused)),
-	char**	argv)
-{
-	char	client_key[] = "../SSL/client-key.pem",	client_cert[] = "../SSL/client-cert.pem";
-	char	ca_file[] = "../SSL/cacert.pem",	*ca_path = 0, *cipher=0;
-	struct st_VioSSLFd* ssl_connector= 0;
-	struct sockaddr_in sa;
-	Vio* client_vio=0;
-	int err;
-	char	xbuf[100]="Ohohhhhoh1234";
-	MY_INIT(argv[0]);
-        DBUG_PROCESS(argv[0]);
-        DBUG_PUSH(default_dbug_option);
-
-	printf("Client key/cert : %s/%s\n", client_key, client_cert);
-	if (ca_file!=0)
-		printf("CAfile          : %s\n", ca_file);
-	if (ca_path!=0)
-		printf("CApath          : %s\n", ca_path);
-
-	ssl_connector = new_VioSSLConnectorFd(client_key, client_cert, ca_file, ca_path, cipher);
-	if(!ssl_connector) {
-                 fatal_error("client:new_VioSSLConnectorFd failed");
-	}
-
-	/* ----------------------------------------------- */
-	/* Create a socket and connect to server using normal socket calls. */
-
-	client_vio = vio_new(socket (AF_INET, SOCK_STREAM, 0), VIO_TYPE_TCPIP, TRUE);
-
-	memset (&sa, '\0', sizeof(sa));
-	sa.sin_family      = AF_INET;
-	sa.sin_addr.s_addr = inet_addr ("127.0.0.1");   /* Server IP */
-	sa.sin_port        = htons     (1111);          /* Server Port number */
-
-	err = connect(client_vio->sd, (struct sockaddr*) &sa,
-		sizeof(sa));
-
-	/* ----------------------------------------------- */
-	/* Now we have TCP conncetion. Start SSL negotiation. */
-	read(client_vio->sd,xbuf, sizeof(xbuf));
-        sslconnect(ssl_connector,client_vio,60L);
-	err = vio_read(client_vio,xbuf, sizeof(xbuf));
-	if (err<=0) {
-		my_free((uchar*)ssl_connector,MYF(0));
-		fatal_error("client:SSL_read");
-	}
-	xbuf[err] = 0;
-	printf("client:got %s\n", xbuf);
-	my_free((uchar*)client_vio,MYF(0));
-	my_free((uchar*)ssl_connector,MYF(0));
-	return 0;
-}
-#else /* HAVE_OPENSSL */
-
-int main() {
-return 0;
-}
-#endif /* HAVE_OPENSSL */

=== removed file 'vio/test-sslserver.c'
--- vio/test-sslserver.c	2008-06-25 05:29:13 +0000
+++ vio/test-sslserver.c	1970-01-01 00:00:00 +0000
@@ -1,155 +0,0 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-#include <my_global.h>
-#ifdef HAVE_OPENSSL
-#include <my_sys.h>
-#include <m_string.h>
-#include <m_ctype.h>
-#include "mysql.h"
-#include "errmsg.h"
-#include <my_dir.h>
-#include <my_getopt.h>
-#include <signal.h>
-#include <violite.h>
-
-const char *VER="0.2";
-
-
-#ifndef DBUG_OFF
-const char *default_dbug_option="d:t:O,-";
-#endif
-
-#if 0
-static void
-fatal_error(	const char*	r)
-{
-	perror(r);
-	exit(0);
-}
-#endif
-
-typedef struct {
-	int	sd;
-	struct	st_VioSSLFd*	ssl_acceptor;
-} TH_ARGS;
-
-static void
-do_ssl_stuff(	TH_ARGS*	args)
-{
-	const char*	s = "Huhuhuhuuu";
-	Vio*		server_vio;
-	int		err;
-	DBUG_ENTER("do_ssl_stuff");
-
-	server_vio = vio_new(args->sd, VIO_TYPE_TCPIP, TRUE);
-
-	/* ----------------------------------------------- */
-	/* TCP connection is ready. Do server side SSL. */
-
-	err = write(server_vio->sd,(uchar*)s, strlen(s));
-	sslaccept(args->ssl_acceptor,server_vio,60L);
-	err = server_vio->write(server_vio,(uchar*)s, strlen(s));
-	DBUG_VOID_RETURN;
-}
-
-static void*
-client_thread(	void*	arg)
-{
-  my_thread_init();
-  do_ssl_stuff((TH_ARGS*)arg);
-  return 0;
-}
-
-int
-main(int argc __attribute__((unused)), char** argv)
-{
-	char	server_key[] = "../SSL/server-key.pem",
-		server_cert[] = "../SSL/server-cert.pem";
-	char	ca_file[] = "../SSL/cacert.pem",
-		*ca_path = 0,
-		*cipher = 0;
-	struct	st_VioSSLFd*	ssl_acceptor;
-	pthread_t	th;
-	TH_ARGS		th_args;
-
-
-	struct sockaddr_in sa_serv;
-	struct sockaddr_in sa_cli;
-	int listen_sd;
-	int err;
-        size_socket client_len;
-	int	reuseaddr = 1; /* better testing, uh? */
-
-	MY_INIT(argv[0]);
-        DBUG_PROCESS(argv[0]);
-        DBUG_PUSH(default_dbug_option);
-
-	printf("Server key/cert : %s/%s\n", server_key, server_cert);
-	if (ca_file!=0)
-
-		printf("CAfile          : %s\n", ca_file);
-	if (ca_path!=0)
-		printf("CApath          : %s\n", ca_path);
-
-        th_args.ssl_acceptor = ssl_acceptor = new_VioSSLAcceptorFd(server_key, server_cert, ca_file, ca_path,cipher);
-
-	/* ----------------------------------------------- */
-	/* Prepare TCP socket for receiving connections */
-
-	listen_sd = socket (AF_INET, SOCK_STREAM, 0);
-	setsockopt(listen_sd, SOL_SOCKET, SO_REUSEADDR, &reuseaddr, sizeof(&reuseaddr));
-
-	memset (&sa_serv, '\0', sizeof(sa_serv));
-	sa_serv.sin_family      = AF_INET;
-	sa_serv.sin_addr.s_addr = INADDR_ANY;
-	sa_serv.sin_port        = htons (1111);          /* Server Port number */
-
-	err = bind(listen_sd, (struct sockaddr*) &sa_serv,
-	     sizeof (sa_serv));                  
-
-	/* Receive a TCP connection. */
-
-	err = listen (listen_sd, 5); 
-	client_len = sizeof(sa_cli);
-	th_args.sd = accept (listen_sd, (struct sockaddr*) &sa_cli, &client_len);
-	close (listen_sd);
-
-	printf ("Connection from %lx, port %x\n",
-		  (long)sa_cli.sin_addr.s_addr, sa_cli.sin_port);
-
-	/* ----------------------------------------------- */
-	/* TCP connection is ready. Do server side SSL. */
-
-	err = pthread_create(&th, NULL, client_thread, (void*)&th_args);
-	DBUG_PRINT("info", ("pthread_create: %d", err));
-	pthread_join(th, NULL);
-
-#if 0
-	if (err<=0) {
-		my_free((uchar*)ssl_acceptor,MYF(0));
-		fatal_error("server:SSL_write");
-	}
-#endif /* 0 */
-
-	my_free((uchar*)ssl_acceptor,MYF(0));
-	return 0;
-}
-#else /* HAVE_OPENSSL */
-
-int main() {
-return 0;
-}
-#endif /* HAVE_OPENSSL */

